pub struct ObjectEntry {
pub key: Strand,
pub value: Expr,
}Expand description
A hack to convert objects to geometries like they previously would. If it fails to convert to geometry it just returns an object like previous behaviour>
The behaviour around geometries needs to be improved but until then this is her to ensure they still work like they previously would.
Fields
key: Strandvalue: ExprTrait Implementations
Sourceimpl Clone for ObjectEntry
impl Clone for ObjectEntry
Sourceimpl Debug for ObjectEntry
impl Debug for ObjectEntry
impl Eq for ObjectEntry
Sourceimpl PartialEq for ObjectEntry
impl PartialEq for ObjectEntry
impl StructuralPartialEq for ObjectEntry