BindingPower

Enum BindingPower 

pub enum BindingPower {
Show 13 variants Base, Nullish, Or, And, Equality, Relation, AddSub, MulDiv, Power, Prefix, Range, Call, Prime,
}
An enum which defines how strong a operator binds it’s operands.

If a binding power is higher the operator is more likely to directly operate on it’s neighbours.

Variants



Base



Nullish



Or



And



Equality



Relation



AddSub



MulDiv



Power



Prefix



Range



Call



Prime

Implementations

Source

impl BindingPower

pub fn for_binary_operator(op: &BinaryOperator) -> Self

Returns the binding power of this operator.

Note that there are some variants here which can have multiple meanings. Operator::Equal can be assignment but can also be equality. Operator::Add can be the add operator but also the plus prefix operator which have different binding powers.

This function returns the binding power for if the operator is used in the infix position.

pub fn for_postfix_operator(op: &PostfixOperator) -> Self

pub fn for_prefix_operator(op: &PrefixOperator) -> Self

pub fn for_expr(expr: &Expr) -> BindingPower

Returns the binding power for this expression. This is generally BindingPower::Prime as most value variants are prime expressions, however some like Value::Expression and Value::Range have a different binding power.